<?php
/**
 * Page metaboxes
 *
 * @package xts
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Direct access not allowed.
}

use XTS\Metaboxes;

if ( ! function_exists( 'cheshalo_register_page_metaboxes' ) ) {
	/**
	 * Register page metaboxes
	 *
	 * @since 1.0.0
	 */
	function cheshalo_register_page_metaboxes() {
		global $cheshalo_transfer_options, $cheshalo_prefix;

		$cheshalo_prefix = '_cheshalo_';

		$page_metabox = Metaboxes::add_metabox(
			array(
				'id'         => 'xts_page_metaboxes',
				'title'      => esc_html__( 'Page Setting (custom metabox from theme)', 'cheshalo' ),
				'post_types' => array( 'page', 'post', 'portfolio' ),
			)
		);

		$page_metabox->add_section(
			array(
				'id'       => 'header',
				'name'     => esc_html__( 'Header', 'cheshalo' ),
				'priority' => 10,
				'icon'     => 'xts-i-header-builder',
			)
		);

		$page_metabox->add_section(
			array(
				'id'       => 'page_title',
				'name'     => esc_html__( 'Page title', 'cheshalo' ),
				'priority' => 20,
				'icon'     => 'xts-i-page-title',
			)
		);

		$page_metabox->add_section(
			array(
				'id'       => 'sidebar',
				'name'     => esc_html__( 'Sidebar', 'cheshalo' ),
				'priority' => 30,
				'icon'     => 'xts-i-sidebars',
			)
		);

		$page_metabox->add_section(
			array(
				'id'       => 'footer',
				'name'     => esc_html__( 'Footer', 'cheshalo' ),
				'priority' => 40,
				'icon'     => 'xts-i-footer',
			)
		);

		$page_metabox->add_section(
			array(
				'id'         => 'mobile',
				'name'       => esc_html__( 'Mobile version', 'cheshalo' ),
				'priority'   => 50,
				'icon'       => 'xts-i-phone',
				'post_types' => array( 'page' ),
			)
		);

		$page_metabox->add_field(
			array(
				'id'           => $cheshalo_prefix . 'mobile_content',
				'name'         => esc_html__( 'Mobile version HTML block (experimental)', 'cheshalo' ),
				'description'  => esc_html__( 'You can create a separate content that will be displayed on mobile devices to optimize the performance.', 'cheshalo' ),
				'type'         => 'select',
				'section'      => 'mobile',
				'select2'      => true,
				'empty_option' => true,
				'autocomplete' => array(
					'type'   => 'post',
					'value'  => 'cms_block',
					'search' => 'cheshalo_get_post_by_query_autocomplete',
					'render' => 'cheshalo_get_post_by_ids_autocomplete',
				),
				'priority'     => 10,
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'open_categories',
				'type'        => 'checkbox',
				'name'        => esc_html__( 'Open categories menu', 'cheshalo' ),
				'hint'        => wp_kses( __( '<img data-src="' . CHESHALO_TOOLTIP_URL . 'open-categories-menu.jpg" alt="">', 'cheshalo' ), true ),
				'description' => esc_html__( 'Always shows categories navigation on this page', 'cheshalo' ),
				'section'     => 'header',
				'on-text'     => esc_html__( 'Yes', 'cheshalo' ),
				'off-text'    => esc_html__( 'No', 'cheshalo' ),
				'priority'    => 10,
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'whb_header',
				'name'        => esc_html__( 'Custom header for this page', 'cheshalo' ),
				'description' => esc_html__( 'If you are using our header builder for your header configuration you can select different layout from the list for this particular page.', 'cheshalo' ),
				'type'        => 'select',
				'section'     => 'header',
				'options'     => '',
				'callback'    => 'cheshalo_get_theme_settings_headers_array',
				'default'     => 'inherit',
				'priority'    => 20,
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'title_off',
				'type'        => 'checkbox',
				'name'        => esc_html__( 'Disable page title', 'cheshalo' ),
				'hint'        => '<video data-src="' . CHESHALO_TOOLTIP_URL . 'disable-page-title.mp4" autoplay loop muted></video>',
				'description' => esc_html__( 'You can hide page heading for this page', 'cheshalo' ),
				'section'     => 'page_title',
				'on-text'     => esc_html__( 'Yes', 'cheshalo' ),
				'off-text'    => esc_html__( 'No', 'cheshalo' ),
				'priority'    => 30,
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'page-title-size',
				'name'        => esc_html__( 'Page title size', 'cheshalo' ),
				'description' => esc_html__( 'You can set different sizes for your page titles.', 'cheshalo' ),
				'type'        => 'buttons',
				'section'     => 'page_title',
				'options'     => array(
					'inherit' => array(
						'name'  => esc_html__( 'Inherit', 'cheshalo' ),
						'value' => 'inherit',
					),
					'default' => array(
						'name'  => esc_html__( 'Default', 'cheshalo' ),
						'hint'     => wp_kses( __( '<img data-src="' . CHESHALO_TOOLTIP_URL . 'page-title-size-default.jpg" alt="">', 'cheshalo' ), true ),
						'value' => 'default',
					),
					'small'   => array(
						'name'  => esc_html__( 'Small', 'cheshalo' ),
						'hint'     => wp_kses( __( '<img data-src="' . CHESHALO_TOOLTIP_URL . 'page-title-size-small.jpg" alt="">', 'cheshalo' ), true ),
						'value' => 'small',
					),
					'large'   => array(
						'name'  => esc_html__( 'Large', 'cheshalo' ),
						'hint'     => wp_kses( __( '<img data-src="' . CHESHALO_TOOLTIP_URL . 'page-title-size-large.jpg" alt="">', 'cheshalo' ), true ),
						'value' => 'large',
					),
				),
				'default'     => 'inherit',
				'priority'    => 40,
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'title_image',
				'type'        => 'upload',
				'name'        => esc_html__( 'Image for page title', 'cheshalo' ),
				'description' => esc_html__( 'Upload an image', 'cheshalo' ),
				'section'     => 'page_title',
				'priority'    => 50,
				'class'       => 'xts-col-6',
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'title_bg_color',
				'type'        => 'color',
				'name'        => esc_html__( 'Page title background color', 'cheshalo' ),
				'description' => esc_html__( 'Choose a color', 'cheshalo' ),
				'section'     => 'page_title',
				'data_type'   => 'hex',
				'priority'    => 60,
				'class'       => 'xts-col-6',
			)
		);

		$page_metabox->add_field(
			array(
				'id'       => $cheshalo_prefix . 'title_color',
				'name'     => esc_html__( 'Text color for title', 'cheshalo' ),
				'type'     => 'buttons',
				'section'  => 'page_title',
				'options'  => array(
					'default' => array(
						'name'  => esc_html__( 'Inherit', 'cheshalo' ),
						'value' => 'default',
					),
					'light'   => array(
						'name'  => esc_html__( 'Light', 'cheshalo' ),
						'value' => 'light',
					),
					'dark'    => array(
						'name'  => esc_html__( 'Dark', 'cheshalo' ),
						'value' => 'dark',
					),
				),
				'default'  => 'default',
				'priority' => 70,
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'main_layout',
				'name'        => esc_html__( 'Sidebar position', 'cheshalo' ),
				'description' => esc_html__( 'Select main content and sidebar alignment.', 'cheshalo' ),
				'type'        => 'buttons',
				'section'     => 'sidebar',
				'options'     => array(
					'default'       => array(
						'name'  => esc_html__( 'Inherit', 'cheshalo' ),
						'value' => 'default',
					),
					'full-width'    => array(
						'name'  => esc_html__( 'Without', 'cheshalo' ),
						'value' => 'full-width',
					),
					'sidebar-left'  => array(
						'name'  => esc_html__( 'Left', 'cheshalo' ),
						'value' => 'sidebar-left',
					),
					'sidebar-right' => array(
						'name'  => esc_html__( 'Right', 'cheshalo' ),
						'value' => 'sidebar-right',
					),
				),
				'default'     => 'default',
				'priority'    => 80,
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'sidebar_width',
				'name'        => esc_html__( 'Sidebar size', 'cheshalo' ),
				'description' => esc_html__( 'You can set different sizes for your pages sidebar', 'cheshalo' ),
				'type'        => 'buttons',
				'section'     => 'sidebar',
				'options'     => array(
					'default' => array(
						'name'  => esc_html__( 'Inherit', 'cheshalo' ),
						'value' => 'default',
					),
					2         => array(
						'name'  => esc_html__( 'Small', 'cheshalo' ),
						'value' => 2,
					),
					3         => array(
						'name'  => esc_html__( 'Medium', 'cheshalo' ),
						'value' => 3,
					),
					4         => array(
						'name'  => esc_html__( 'Large', 'cheshalo' ),
						'value' => 4,
					),
				),
				'default'     => 'default',
				'priority'    => 90,
				'class'       => 'xts-tooltip-bordered',
			)
		);

		$cheshalo_transfer_options[] = 'page-title-size';
		$cheshalo_transfer_options[] = 'main_layout';
		$cheshalo_transfer_options[] = 'sidebar_width';

		$page_metabox->add_field(
			array(
				'id'       => $cheshalo_prefix . 'custom_sidebar',
				'name'     => esc_html__( 'Custom sidebar for this page', 'cheshalo' ),
				'type'     => 'select',
				'section'  => 'sidebar',
				'options'  => '',
				'callback' => 'cheshalo_get_theme_settings_sidebars_array',
				'priority' => 100,
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'footer_off',
				'type'        => 'checkbox',
				'name'        => esc_html__( 'Disable footer', 'cheshalo' ),
				'hint'        => wp_kses( __( '<img data-src="' . CHESHALO_TOOLTIP_URL . 'disable-footer.jpg" alt="">', 'cheshalo' ), true ),
				'description' => esc_html__( 'You can disable footer for this page', 'cheshalo' ),
				'section'     => 'footer',
				'on-text'     => esc_html__( 'Yes', 'cheshalo' ),
				'off-text'    => esc_html__( 'No', 'cheshalo' ),
				'priority'    => 110,
				'class'       => 'xts-tooltip-bordered',
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'prefooter_off',
				'type'        => 'checkbox',
				'name'        => esc_html__( 'Disable prefooter', 'cheshalo' ),
				'hint'        => wp_kses( __( '<img data-src="' . CHESHALO_TOOLTIP_URL . 'disable-prefooter.jpg" alt="">', 'cheshalo' ), true ),
				'description' => esc_html__( 'You can disable prefooter for this page', 'cheshalo' ),
				'section'     => 'footer',
				'on-text'     => esc_html__( 'Yes', 'cheshalo' ),
				'off-text'    => esc_html__( 'No', 'cheshalo' ),
				'priority'    => 120,
				'class'       => 'xts-tooltip-bordered',
			)
		);

		$page_metabox->add_field(
			array(
				'id'          => $cheshalo_prefix . 'copyrights_off',
				'type'        => 'checkbox',
				'name'        => esc_html__( 'Disable copyrights', 'cheshalo' ),
				'hint'        => wp_kses( __( '<img data-src="' . CHESHALO_TOOLTIP_URL . 'disable-copyrights.jpg" alt="">', 'cheshalo' ), true ),
				'description' => esc_html__( 'You can disable copyrights for this page', 'cheshalo' ),
				'section'     => 'footer',
				'on-text'     => esc_html__( 'Yes', 'cheshalo' ),
				'off-text'    => esc_html__( 'No', 'cheshalo' ),
				'priority'    => 130,
				'class'       => 'xts-tooltip-bordered',
			)
		);
	}

	add_action( 'init', 'cheshalo_register_page_metaboxes', 100 );
}


$post_category_metabox = Metaboxes::add_metabox(
	array(
		'id'         => 'xts_post_category_metaboxes',
		'title'      => esc_html__( 'Extra options from theme', 'cheshalo' ),
		'object'     => 'term',
		'taxonomies' => array( 'category' ),
	)
);

$post_category_metabox->add_section(
	array(
		'id'       => 'general',
		'name'     => esc_html__( 'General', 'cheshalo' ),
		'icon'     => 'dashicons dashicons-welcome-write-blog',
		'priority' => 10,
	)
);

$post_category_metabox->add_field(
	array(
		'id'          => '_cheshalo_blog_design',
		'name'        => esc_html__( 'Blog design', 'cheshalo' ),
		'description' => esc_html__( 'Choose one of the blog designs available in the theme.', 'cheshalo' ),
		'type'        => 'select',
		'section'     => 'general',
		'options'     => array(
			'inherit'      => array(
				'name'  => esc_html__( 'Inherit', 'cheshalo' ),
				'value' => 'inherit',
			),
			'default'      => array(
				'name'  => esc_html__( 'Default', 'cheshalo' ),
				'value' => 'Default',
			),
			'default-alt'  => array(
				'name'  => esc_html__( 'Default alternative', 'cheshalo' ),
				'value' => 'default-alt',
			),
			'small-images' => array(
				'name'  => esc_html__( 'Small images', 'cheshalo' ),
				'value' => 'small-images',
			),
			'chess'        => array(
				'name'  => esc_html__( 'Chess', 'cheshalo' ),
				'value' => 'chess',
			),
			'masonry'      => array(
				'name'  => esc_html__( 'Masonry grid', 'cheshalo' ),
				'value' => 'default',
			),
			'mask'         => array(
				'name'  => esc_html__( 'Mask on image', 'cheshalo' ),
				'value' => 'mask',
			),
			'meta-image'   => array(
				'name'  => esc_html__( 'Meta on image', 'cheshalo' ),
				'value' => 'meta-image',
			),
		),
		'priority'    => 10,
	)
);
