<?php if ( ! defined( 'CHESHALO_THEME_DIR' ) ) exit( 'No direct script access allowed' );
/**
* ------------------------------------------------------------------------------------------------
* Social buttons element map
* ------------------------------------------------------------------------------------------------
*/

if( ! function_exists( 'cheshalo_get_social_buttons_shortcode_args' ) ) {
	function cheshalo_get_social_buttons_shortcode_args() {
		return array(
			'name' => esc_html__( 'Social buttons', 'cheshalo' ),
			'base' => 'social_buttons',
			'category' => function_exists( 'cheshalo_get_tab_title_category_for_wpb' ) ? cheshalo_get_tab_title_category_for_wpb( esc_html__( 'Theme elements', 'cheshalo' ) ) : esc_html__( 'Theme elements', 'cheshalo' ),
			'description' => esc_html__( 'Follow or share buttons', 'cheshalo' ),
        	'icon' => CHESHALO_ASSETS . '/images/vc-icon/social-buttons.svg',
			'params' => cheshalo_get_social_shortcode_params()
		);
	}
}

if( ! function_exists( 'cheshalo_get_social_shortcode_params' ) ) {
	function cheshalo_get_social_shortcode_params() {
		$typography = array();

		if ( function_exists( 'cheshalo_get_typography_map' ) ) {
			$typography = cheshalo_get_typography_map(
				array(
					'key'        => 'label',
					'selector'   => '{{WRAPPER}} .wd-label',
					'dependency' => array(
						'element' => 'show_label',
						'value'   => 'yes',
					),
					'group'      => esc_html__( 'Style', 'js_composer' ),
				)
			);
		}

		return apply_filters( 'cheshalo_get_social_shortcode_params', array(
			/**
			* Type
			*/
			array(
				'type' => 'cheshalo_title_divider',
				'holder' => 'div',
				'title' => esc_html__( 'General', 'cheshalo' ),
				'param_name' => 'type_divider'
			),

			array(
				'type'       => 'cheshalo_css_id',
				'param_name' => 'cheshalo_css_id',
			),

			array(
				'heading'          => esc_html__( 'Label', 'cheshalo' ),
				'type'             => 'cheshalo_switch',
				'param_name'       => 'show_label',
				'true_state'       => 'yes',
				'false_state'      => 'no',
				'default'          => 'no',
				'edit_field_class' => 'vc_col-sm-6 vc_column',
			),

			array(
				'heading'          => esc_html__( 'Label text', 'cheshalo' ),
				'type'             => 'textfield',
				'param_name'       => 'label_text',
				'value'            => esc_html__( 'Share: ', 'cheshalo' ),
				'dependency'       => array(
					'element' => 'show_label',
					'value'   => 'yes',
				),
				'edit_field_class' => 'vc_col-sm-6 vc_column',
			),

			array(
				'type' => 'cheshalo_button_set',
				'heading' => esc_html__( 'Buttons type', 'cheshalo' ),
				'param_name' => 'type',
				'value' => array(
					esc_html__( 'Share', 'cheshalo' ) => 'share',
					esc_html__( 'Follow', 'cheshalo' ) => 'follow'
				),
			),

			/**
			* Extra
			*/
			array(
				'type' => 'cheshalo_title_divider',
				'holder' => 'div',
				'title' => esc_html__( 'Extra options', 'cheshalo' ),
				'param_name' => 'extra_divider'
			),
			( function_exists( 'vc_map_add_css_animation' ) ) ? vc_map_add_css_animation( true ) : '',
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Extra class name', 'cheshalo' ),
				'param_name' => 'el_class',
				'hint' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' )
			),

			/**
			 * Style tab.
			 */
			// General.
			array(
				'type'       => 'cheshalo_title_divider',
				'holder'     => 'div',
				'title'      => esc_html__( 'General', 'cheshalo' ),
				'param_name' => 'style_general_divider',
				'group'      => esc_html__( 'Style', 'js_composer' ),
			),
			array(
				'heading'          => esc_html__( 'Layout', 'cheshalo' ),
				'type'             => 'dropdown',
				'param_name'       => 'layout',
				'value'            => array(
					esc_html__( 'Default', 'cheshalo' ) => 'default',
					esc_html__( 'Inline', 'cheshalo' )  => 'inline',
					esc_html__( 'Justify', 'cheshalo' ) => 'justify',
				),
				'dependency'       => array(
					'element' => 'show_label',
					'value'   => 'yes',
				),
				'group'            => esc_html__( 'Style', 'js_composer' ),
				'edit_field_class' => 'vc_col-sm-6 vc_column',
			),
			array(
				'type'             => 'cheshalo_image_select',
				'heading'          => esc_html__( 'Align ', 'cheshalo' ),
				'param_name'       => 'align',
				'value'            => array(
					esc_html__( 'Left', 'cheshalo' )   => 'left',
					esc_html__( 'Center', 'cheshalo' ) => 'center',
					esc_html__( 'Right', 'cheshalo' )  => 'right',
				),
				'images_value'     => array(
					'center' => CHESHALO_ASSETS_IMAGES . '/settings/align/center.jpg',
					'left'   => CHESHALO_ASSETS_IMAGES . '/settings/align/left.jpg',
					'right'  => CHESHALO_ASSETS_IMAGES . '/settings/align/right.jpg',
				),
				'std'              => 'center',
				'wood_tooltip'     => true,
				'group'            => esc_html__( 'Style', 'js_composer' ),
				'edit_field_class' => 'vc_col-sm-6 vc_column title-align',
			),
			// Icons.
			array(
				'type'       => 'cheshalo_title_divider',
				'holder'     => 'div',
				'title'      => esc_html__( 'Icons', 'cheshalo' ),
				'param_name' => 'style_icons_divider',
				'group'      => esc_html__( 'Style', 'js_composer' ),
			),

			array(
				'type'             => 'cheshalo_image_select',
				'heading'          => esc_html__( 'Button style', 'cheshalo' ),
				'param_name'       => 'style',
				'value'            => array(
					esc_html__( 'Default', 'cheshalo' )  => '',
					esc_html__( 'Simple', 'cheshalo' )   => 'simple',
					esc_html__( 'Colored', 'cheshalo' )  => 'colored',
					esc_html__( 'Colored alternative', 'cheshalo' ) => 'colored-alt',
					esc_html__( 'Bordered', 'cheshalo' ) => 'bordered',
				),
				'images_value'     => array(
					''            => CHESHALO_ASSETS_IMAGES . '/settings/social-buttons/style/default.png',
					'simple'      => CHESHALO_ASSETS_IMAGES . '/settings/social-buttons/style/simple.png',
					'colored'     => CHESHALO_ASSETS_IMAGES . '/settings/social-buttons/style/colored.png',
					'colored-alt' => CHESHALO_ASSETS_IMAGES . '/settings/social-buttons/style/colored-alt.png',
					'bordered'    => CHESHALO_ASSETS_IMAGES . '/settings/social-buttons/style/bordered.png',
				),
				'wood_tooltip'     => true,
				'std'              => '',
				'group'            => esc_html__( 'Style', 'js_composer' ),
				'edit_field_class' => 'vc_col-xs-12 vc_column social-style',
			),
			array(
				'type'             => 'cheshalo_image_select',
				'heading'          => esc_html__( 'Button form', 'cheshalo' ),
				'param_name'       => 'form',
				'value'            => array(
					esc_html__( 'Circle', 'cheshalo' ) => 'circle',
					esc_html__( 'Square', 'cheshalo' ) => 'square',
				),
				'images_value'     => array(
					'circle' => CHESHALO_ASSETS_IMAGES . '/settings/social-buttons/shape/circle.png',
					'square' => CHESHALO_ASSETS_IMAGES . '/settings/social-buttons/shape/square.png',
				),
				'wood_tooltip'     => true,
				'std'              => 'circle',
				'group'            => esc_html__( 'Style', 'js_composer' ),
				'edit_field_class' => 'vc_col-xs-12 vc_column social-form',
			),
			array(
				'type'             => 'dropdown',
				'heading'          => esc_html__( 'Buttons size', 'cheshalo' ),
				'param_name'       => 'size',
				'value'            => array(
					esc_html__( 'Default (18px)', 'cheshalo' ) => '',
					esc_html__( 'Small (14px)', 'cheshalo' ) => 'small',
					esc_html__( 'Large (22px)', 'cheshalo' ) => 'large',
				),
				'group'            => esc_html__( 'Style', 'js_composer' ),
				'edit_field_class' => 'vc_col-sm-6 vc_column',
			),
			array(
				'type'             => 'cheshalo_button_set',
				'heading'          => esc_html__( 'Color', 'cheshalo' ),
				'param_name'       => 'color',
				'value'            => array(
					esc_html__( 'Dark', 'cheshalo' )  => 'dark',
					esc_html__( 'Light', 'cheshalo' ) => 'light',
				),
				'group'            => esc_html__( 'Style', 'js_composer' ),
				'edit_field_class' => 'vc_col-sm-6 vc_column',
			),
			// Label.
			array(
				'type'       => 'cheshalo_title_divider',
				'holder'     => 'div',
				'title'      => esc_html__( 'Label', 'cheshalo' ),
				'param_name' => 'style_label_divider',
				'dependency' => array(
					'element' => 'show_label',
					'value'   => 'yes',
				),
				'group'      => esc_html__( 'Style', 'js_composer' ),
			),
			function_exists( 'cheshalo_get_typography_map' ) ? $typography['font_family'] : '',
			function_exists( 'cheshalo_get_typography_map' ) ? $typography['font_size'] : '',
			function_exists( 'cheshalo_get_typography_map' ) ? $typography['font_weight'] : '',
			function_exists( 'cheshalo_get_typography_map' ) ? $typography['text_transform'] : '',
			function_exists( 'cheshalo_get_typography_map' ) ? $typography['font_style'] : '',
			function_exists( 'cheshalo_get_typography_map' ) ? $typography['line_height'] : '',
			array(
				'heading'          => esc_html__( 'Label color', 'cheshalo' ),
				'type'             => 'wd_colorpicker',
				'param_name'       => 'label_color',
				'selectors'        => array(
					'{{WRAPPER}} .wd-label' => array(
						'color: {{VALUE}};',
					),
				),
				'dependency'       => array(
					'element' => 'show_label',
					'value'   => 'yes',
				),
				'group'            => esc_html__( 'Style', 'js_composer' ),
				'edit_field_class' => 'vc_col-sm-6 vc_column',
			),
			/**
			 * Design Options tab.
			 */
			array(
				'type'       => 'css_editor',
				'heading'    => esc_html__( 'CSS box', 'cheshalo' ),
				'param_name' => 'css',
				'group'      => esc_html__( 'Design Options', 'js_composer' ),
			),
			function_exists( 'cheshalo_get_vc_responsive_spacing_map' ) ? cheshalo_get_vc_responsive_spacing_map() : '',

			/**
			 * Advanced tab.
			 */

			// Width option (with dependency Columns option, responsive).
			cheshalo_get_responsive_dependency_width_map( 'responsive_tabs' ),
			cheshalo_get_responsive_dependency_width_map( 'width_desktop' ),
			cheshalo_get_responsive_dependency_width_map( 'custom_width_desktop' ),
			cheshalo_get_responsive_dependency_width_map( 'width_tablet' ),
			cheshalo_get_responsive_dependency_width_map( 'custom_width_tablet' ),
			cheshalo_get_responsive_dependency_width_map( 'width_mobile' ),
			cheshalo_get_responsive_dependency_width_map( 'custom_width_mobile' ),
		) );
	}
}
