<?php if ( ! defined( 'CHESHALO_THEME_DIR' ) ) exit( 'No direct script access allowed' );
/**
* ------------------------------------------------------------------------------------------------
* Team Member element map
* ------------------------------------------------------------------------------------------------
*/

if ( ! function_exists( 'cheshalo_get_vc_map_team_member' ) ) {
	function cheshalo_get_vc_map_team_member() {
		$name_typography = cheshalo_get_typography_map(
			array(
				'title'    => esc_html__( 'Name typography', 'cheshalo' ),
				'key'      => 'name_typography',
				'selector' => '{{WRAPPER}}.team-member .member-name',
			)
		);

		$position_typography = cheshalo_get_typography_map(
			array(
				'title'    => esc_html__( 'Position typography', 'cheshalo' ),
				'key'      => 'position_typography',
				'selector' => '{{WRAPPER}}.team-member .member-position',
			)
		);

		return array(
			'name' => esc_html__( 'Team Member', 'cheshalo' ),
			'base' => 'team_member',
			'category' => cheshalo_get_tab_title_category_for_wpb( esc_html__( 'Theme elements', 'cheshalo' ) ),
			'description' => esc_html__( 'Display information about some person', 'cheshalo' ),
			'icon' => CHESHALO_ASSETS . '/images/vc-icon/team-member.svg',
			'params' => array(
				array(
					'type'       => 'cheshalo_css_id',
					'param_name' => 'cheshalo_css_id',
				),
				/**
				 * Image
				 */
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Image', 'cheshalo' ),
					'param_name' => 'image_divider'
				),
				array(
					'type' => 'attach_image',
					'heading' => esc_html__( 'User Avatar', 'cheshalo' ),
					'param_name' => 'image',
					'value' => '',
					'hint' => esc_html__( 'Select image from media library.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Image size', 'cheshalo' ),
					'param_name' => 'img_size',
					'hint' => esc_html__( 'Enter image size. Example: \'thumbnail\', \'medium\', \'large\', \'full\' or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use \'thumbnail\' size.', 'cheshalo' ),
					'description' => esc_html__( 'Example: \'thumbnail\', \'medium\', \'large\', \'full\' or enter image size in pixels: \'200x100\'.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				/**
				 * Content
				 */
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Content', 'cheshalo' ),
					'param_name' => 'content_divider'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Name', 'cheshalo' ),
					'param_name' => 'name',
					'value' => '',
					'hint' => esc_html__( 'Enter the person’s name.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				$name_typography['font_family'],
				$name_typography['font_size'],
				$name_typography['font_weight'],
				$name_typography['text_transform'],
				$name_typography['font_style'],
				$name_typography['line_height'],
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Position', 'cheshalo' ),
					'param_name' => 'position',
					'value' => '',
					'hint' => esc_html__( 'Enter the person’s title or job position. For example: CEO or Senior Developer.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				$position_typography['font_family'],
				$position_typography['font_size'],
				$position_typography['font_weight'],
				$position_typography['text_transform'],
				$position_typography['font_style'],
				$position_typography['line_height'],
				array(
					'type' => 'textarea_html',
					'heading' => esc_html__( 'Text', 'cheshalo' ),
					'param_name' => 'content',
					'hint' => esc_html__( 'You can add some member bio here.', 'cheshalo' )
				),
				/**
				 * Layout
				 */
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Layout', 'cheshalo' ),
					'param_name' => 'layout_divider'
				),
				array(
					'type' => 'cheshalo_button_set',
					'heading' => esc_html__( 'Layout', 'cheshalo' ),
					'param_name' => 'layout',
					'value' => array(
						esc_html__( 'Default', 'cheshalo' ) => 'default',
						esc_html__( 'With hover', 'cheshalo' ) => 'hover',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_image_select',
					'heading' => esc_html__( 'Align', 'cheshalo' ),
					'param_name' => 'align',
					'value' => array(
						esc_html__( 'Left', 'cheshalo' ) => 'left',
						esc_html__( 'Center', 'cheshalo' ) => 'center',
						esc_html__( 'Right', 'cheshalo' ) => 'right',
					),
					'images_value' => array(
						'center' => CHESHALO_ASSETS_IMAGES . '/settings/align/center.jpg',
						'left' => CHESHALO_ASSETS_IMAGES . '/settings/align/left.jpg',
						'right' => CHESHALO_ASSETS_IMAGES . '/settings/align/right.jpg',
					),
					'std' => 'left',
					'wood_tooltip' => true,
					'edit_field_class' => 'vc_col-sm-6 vc_column title-align',
				),
				/**
				 * Social links
				 */
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Social links', 'cheshalo' ),
					'param_name' => 'links_divider'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Facebook link', 'cheshalo' ),
					'param_name' => 'facebook',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Twitter link', 'cheshalo' ),
					'param_name' => 'twitter',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Linkedin link', 'cheshalo' ),
					'param_name' => 'linkedin',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Skype link', 'cheshalo' ),
					'param_name' => 'skype',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Instagram link', 'cheshalo' ),
					'param_name' => 'instagram',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				/**
				 * Buttons
				 */
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Buttons', 'cheshalo' ),
					'param_name' => 'buttons_divider'
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Social buttons size', 'cheshalo' ),
					'param_name' => 'size',
					'value' => array(
						esc_html__( 'Default (18px)', 'cheshalo' ) => '',
						esc_html__( 'Small (14px)', 'cheshalo' ) => 'small',
						esc_html__( 'Large (22px)', 'cheshalo' ) => 'large'
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_image_select',
					'heading' => esc_html__( 'Social button style', 'cheshalo' ),
					'param_name' => 'style',
					'value' => array(
						esc_html__( 'Default', 'cheshalo' ) => '',
						esc_html__( 'Simple', 'cheshalo' ) => 'simple',
						esc_html__( 'Colored', 'cheshalo' ) => 'colored',
						esc_html__( 'Colored alternative', 'cheshalo' ) => 'colored-alt',
						esc_html__( 'Bordered', 'cheshalo' ) => 'bordered'
					),
					'images_value' => array(
						'' => CHESHALO_ASSETS_IMAGES . '/settings/social-buttons/style/default.png',
						'simple' => CHESHALO_ASSETS_IMAGES . '/settings/social-buttons/style/simple.png',
						'colored' => CHESHALO_ASSETS_IMAGES . '/settings/social-buttons/style/colored.png',
						'colored-alt' => CHESHALO_ASSETS_IMAGES . '/settings/social-buttons/style/colored-alt.png',
						'bordered' => CHESHALO_ASSETS_IMAGES . '/settings/social-buttons/style/bordered.png',
					),
					'wood_tooltip' => true,
					'std' => 'default',
					'edit_field_class' => 'vc_col-xs-12 vc_column social-style',
				),
				array(
					'type' => 'cheshalo_image_select',
					'heading' => esc_html__( 'Social button form', 'cheshalo' ),
					'param_name' => 'form',
					'value' => array(
						esc_html__( 'Circle', 'cheshalo' ) => 'circle',
						esc_html__( 'Square', 'cheshalo' ) => 'square'
					),
					'images_value' => array(
						'circle' => CHESHALO_ASSETS_IMAGES . '/settings/social-buttons/shape/circle.png',
						'square' => CHESHALO_ASSETS_IMAGES . '/settings/social-buttons/shape/square.png',
					),
					'wood_tooltip' => true,
					'std' => 'default',
					'edit_field_class' => 'vc_col-xs-12 vc_column social-form',
				),
				/**
				 * Extra
				 */
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Extra options', 'cheshalo' ),
					'param_name' => 'extra_divider'
				),
				array(
					'type' => 'cheshalo_button_set',
					'heading' => esc_html__( 'Color Scheme', 'cheshalo' ),
					'param_name' => 'cheshalo_color_scheme',
					'value' => array(
						esc_html__( 'Inherit', 'cheshalo' ) => '',
						esc_html__( 'Light', 'cheshalo' ) => 'light',
						esc_html__( 'Dark', 'cheshalo' ) => 'dark',
					),
				),
				( function_exists( 'vc_map_add_css_animation' ) ) ? vc_map_add_css_animation( true ) : '',
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' )
				),
				/**
				 * Design options
				 */
				array(
					'type'       => 'css_editor',
					'heading'    => esc_html__( 'CSS box', 'cheshalo' ),
					'param_name' => 'css',
					'group'      => esc_html__( 'Design Options', 'js_composer' ),
				),
				cheshalo_get_vc_responsive_spacing_map(),
				/**
				 * Advanced
				 */

				// Width option (with dependency Columns option, responsive).
				cheshalo_get_responsive_dependency_width_map( 'responsive_tabs' ),
				cheshalo_get_responsive_dependency_width_map( 'width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'width_mobile' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_mobile' ),
			),
		);
	}
}
