<?php

if ( ! defined( 'CHESHALO_THEME_DIR' ) ) {
	exit( 'No direct script access allowed' );
}

/**
 * ------------------------------------------------------------------------------------------------
 *  WPBakery Button element
 * ------------------------------------------------------------------------------------------------
 */

if ( ! class_exists( 'CHESHALO_HB_Button' ) ) {
	class CHESHALO_HB_Button extends CHESHALO_HB_Element {

		public function __construct() {
			parent::__construct();
			$this->template_name = 'button';
		}

		public function map() {
			$this->args = array(
				'type'            => 'button',
				'title'           => esc_html__( 'Button', 'cheshalo' ),
				'text'            => esc_html__( 'Button with link', 'cheshalo' ),
				'icon'            => 'xts-i-button',
				'editable'        => true,
				'container'       => false,
				'edit_on_create'  => true,
				'drag_target_for' => array(),
				'drag_source'     => 'content_element',
				'removable'       => true,
				'addable'         => true,
				'params'          => array(
					'title'                       => array(
						'id'    => 'title',
						'title' => esc_html__( 'Title', 'cheshalo' ),
						'tab'   => esc_html__( 'General', 'cheshalo' ),
						'group' => esc_html__( 'Content', 'cheshalo' ),
						'type'  => 'text',
						'value' => '',
					),
					'link'                        => array(
						'id'    => 'link',
						'title' => esc_html__( 'Link', 'cheshalo' ),
						'tab'   => esc_html__( 'General', 'cheshalo' ),
						'group' => esc_html__( 'Content', 'cheshalo' ),
						'type'  => 'link',
						'value' => array( 'url' => '' ),
					),
					'button_smooth_scroll'        => array(
						'id'    => 'button_smooth_scroll',
						'title' => esc_html__( 'Smooth scroll', 'cheshalo' ),
						'hint'  => '<video src="' . CHESHALO_TOOLTIP_URL . 'hb_button_smooth_scroll.mp4" autoplay loop muted></video>',
						'tab'   => esc_html__( 'General', 'cheshalo' ),
						'group' => esc_html__( 'Extra', 'cheshalo' ),
						'type'  => 'switcher',
						'value' => false,
						'description' => esc_html__( 'When you turn on this option you need to specify this button link with a hash symbol. For example #section-id Then you need to have a section with an ID of "section-id" and this button click will smoothly scroll the page to that section.', 'cheshalo' ),
					),
					'button_smooth_scroll_time'   => array(
						'id'          => 'button_smooth_scroll_time',
						'title'       => esc_html__( 'Smooth scroll time (ms)', 'cheshalo' ),
						'tab'         => esc_html__( 'General', 'cheshalo' ),
						'group'       => esc_html__( 'Extra', 'cheshalo' ),
						'type'        => 'text',
						'value'       => '',
						'requires'    => array(
							'button_smooth_scroll' => array(
								'comparison' => 'equal',
								'value'      => true,
							),
						),
						'extra_class' => 'xts-col-6',
					),
					'button_smooth_scroll_offset' => array(
						'id'          => 'button_smooth_scroll_offset',
						'title'       => esc_html__( 'Smooth scroll offset (px)', 'cheshalo' ),
						'tab'         => esc_html__( 'General', 'cheshalo' ),
						'group'       => esc_html__( 'Extra', 'cheshalo' ),
						'type'        => 'text',
						'value'       => '',
						'requires'    => array(
							'button_smooth_scroll' => array(
								'comparison' => 'equal',
								'value'      => true,
							),
						),
						'extra_class' => 'xts-col-6',
					),
					'el_class'                    => array(
						'id'          => 'el_class',
						'title'       => esc_html__( 'Additional CSS class', 'cheshalo' ),
						'type'        => 'text',
						'tab'         => esc_html__( 'General', 'cheshalo' ),
						'group'       => esc_html__( 'Extra', 'cheshalo' ),
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' ),
					),
					'style'                       => array(
						'id'      => 'style',
						'title'   => esc_html__( 'Button style', 'cheshalo' ),
						'tab'     => esc_html__( 'Style', 'cheshalo' ),
						'group'   => esc_html__( 'General', 'cheshalo' ),
						'type'    => 'selector',
						'value'   => 'default',
						'options' => array(
							'default'  => array(
								'label' => esc_html__( 'Default', 'cheshalo' ),
								'value' => 'default',
								'image' => CHESHALO_ASSETS_IMAGES . '/settings/buttons/style/default.png',
							),
							'bordered' => array(
								'label' => esc_html__( 'Bordered', 'cheshalo' ),
								'value' => 'bordered',
								'image' => CHESHALO_ASSETS_IMAGES . '/settings/buttons/style/bordered.png',
							),
							'link'     => array(
								'label' => esc_html__( 'Link button', 'cheshalo' ),
								'value' => 'link',
								'image' => CHESHALO_ASSETS_IMAGES . '/settings/buttons/style/link.png',
							),
							'3d'       => array(
								'label' => esc_html__( '3D', 'cheshalo' ),
								'value' => '3d',
								'image' => CHESHALO_ASSETS_IMAGES . '/settings/buttons/style/3d.png',
							),
						),
					),
					'shape'                       => array(
						'id'       => 'shape',
						'title'    => esc_html__( 'Button shape', 'cheshalo' ),
						'tab'      => esc_html__( 'Style', 'cheshalo' ),
						'group'    => esc_html__( 'General', 'cheshalo' ),
						'type'     => 'selector',
						'value'    => 'rectangle',
						'options'  => array(
							'rectangle'  => array(
								'label' => esc_html__( 'Rectangle', 'cheshalo' ),
								'value' => 'rectangle',
								'image' => CHESHALO_ASSETS_IMAGES . '/settings/buttons/shape/rectangle.jpeg',
							),
							'round'      => array(
								'label' => esc_html__( 'Circle', 'cheshalo' ),
								'value' => 'round',
								'image' => CHESHALO_ASSETS_IMAGES . '/settings/buttons/shape/circle.jpeg',
							),
							'semi-round' => array(
								'label' => esc_html__( 'Round', 'cheshalo' ),
								'value' => 'semi-round',
								'image' => CHESHALO_ASSETS_IMAGES . '/settings/buttons/shape/round.jpeg',
							),
						),
						'requires' => array(
							'style' => array(
								'comparison' => 'not_equal',
								'value'      => array( 'round', 'link' ),
							),
						),
					),
					'size'                        => array(
						'id'      => 'size',
						'title'   => esc_html__( 'Button size', 'cheshalo' ),
						'tab'     => esc_html__( 'Style', 'cheshalo' ),
						'group'   => esc_html__( 'General', 'cheshalo' ),
						'type'    => 'select',
						'value'   => 'default',
						'options' => array(
							'default'     => array(
								'label' => esc_html__( 'Default', 'cheshalo' ),
								'value' => 'default',
							),
							'extra-small' => array(
								'label' => esc_html__( 'Extra Small', 'cheshalo' ),
								'value' => 'extra-small',
							),
							'small'       => array(
								'label' => esc_html__( 'Small', 'cheshalo' ),
								'value' => 'small',
							),
							'large'       => array(
								'label' => esc_html__( 'Large', 'cheshalo' ),
								'value' => 'large',
							),
							'extra-large' => array(
								'label' => esc_html__( 'Extra Large', 'cheshalo' ),
								'value' => 'extra-large',
							),
						),
					),
					'color'                       => array(
						'id'      => 'color',
						'title'   => esc_html__( 'Predefined button color', 'cheshalo' ),
						'tab'     => esc_html__( 'Style', 'cheshalo' ),
						'group'   => esc_html__( 'Colors', 'cheshalo' ),
						'type'    => 'select',
						'value'   => 'default',
						'options' => array(
							'default' => array(
								'label' => esc_html__( 'Default', 'cheshalo' ),
								'value' => 'default',
							),
							'primary' => array(
								'label' => esc_html__( 'Primary color', 'cheshalo' ),
								'value' => 'primary',
							),
							'alt'     => array(
								'label' => esc_html__( 'Alternative color', 'cheshalo' ),
								'value' => 'alt',
							),
							'white'   => array(
								'label' => esc_html__( 'White', 'cheshalo' ),
								'value' => 'white',
							),
							'black'   => array(
								'label' => esc_html__( 'Black', 'cheshalo' ),
								'value' => 'black',
							),
						),
					),
					'bg_color'                    => array(
						'id'          => 'bg_color',
						'title'       => esc_html__( 'Background color', 'cheshalo' ),
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Colors', 'cheshalo' ),
						'type'        => 'color',
						'value'       => '',
						'extra_class' => 'xts-col-6',
					),
					'bg_color_hover'              => array(
						'id'          => 'bg_color_hover',
						'title'       => esc_html__( 'Background color on hover', 'cheshalo' ),
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Colors', 'cheshalo' ),
						'type'        => 'color',
						'value'       => '',
						'extra_class' => 'xts-col-6',
					),
					'color_scheme'                => array(
						'id'          => 'color_scheme',
						'title'       => esc_html__( 'Text color scheme', 'cheshalo' ),
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Colors', 'cheshalo' ),
						'type'        => 'selector',
						'value'       => 'light',
						'options'     => array(
							'light'  => array(
								'label' => esc_html__( 'Light', 'cheshalo' ),
								'value' => 'light',
							),
							'dark'   => array(
								'label' => esc_html__( 'Dark', 'cheshalo' ),
								'value' => 'dark',
							),
							'custom' => array(
								'label' => esc_html__( 'Custom', 'cheshalo' ),
								'value' => 'custom',
							),
						),
						'extra_class' => 'xts-col-6',
					),
					'custom_color_scheme'         => array(
						'id'          => 'custom_color_scheme',
						'title'       => esc_html__( 'Custom text color', 'cheshalo' ),
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Colors', 'cheshalo' ),
						'selectors'   => array(
							'{{WRAPPER}}.wd-button-wrapper a' => array(
								'color: {{VALUE}};',
							),
						),
						'type'        => 'color',
						'value'       => '',
						'requires'    => array(
							'color_scheme' => array(
								'comparison' => 'equal',
								'value'      => 'custom',
							),
						),
						'extra_class' => 'xts-col-6',
					),
					'color_scheme_divider'        => array(
						'id'    => 'color_scheme_divider',
						'type'  => 'divider',
						'tab'   => esc_html__( 'Style', 'cheshalo' ),
						'group' => esc_html__( 'Colors', 'cheshalo' ),
						'value' => '',
					),
					'color_scheme_hover'          => array(
						'id'          => 'color_scheme_hover',
						'title'       => esc_html__( 'Text color scheme on hover', 'cheshalo' ),
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Colors', 'cheshalo' ),
						'type'        => 'selector',
						'value'       => 'light',
						'options'     => array(
							'light'  => array(
								'label' => esc_html__( 'Light', 'cheshalo' ),
								'value' => 'light',
							),
							'dark'   => array(
								'label' => esc_html__( 'Dark', 'cheshalo' ),
								'value' => 'dark',
							),
							'custom' => array(
								'label' => esc_html__( 'Custom', 'cheshalo' ),
								'value' => 'custom',
							),
						),
						'extra_class' => 'xts-col-6',
					),
					'custom_color_scheme_hover'   => array(
						'id'          => 'custom_color_scheme_hover',
						'title'       => esc_html__( 'Custom text color on hover', 'cheshalo' ),
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Colors', 'cheshalo' ),
						'selectors'   => array(
							'{{WRAPPER}}.wd-button-wrapper a:hover' => array(
								'color: {{VALUE}};',
							),
						),
						'type'        => 'color',
						'value'       => '',
						'requires'    => array(
							'color_scheme_hover' => array(
								'comparison' => 'equal',
								'value'      => 'custom',
							),
						),
						'extra_class' => 'xts-col-6',
					),
					'icon_library'                => array(
						'id'          => 'icon_library',
						'title'       => esc_html__( 'Icon library', 'cheshalo' ),
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Image', 'cheshalo' ),
						'type'        => 'select',
						'value'       => 'fontawesome',
						'options'     => array(
							'fontawesome' => array(
								'label' => esc_html__( 'Font Awesome', 'cheshalo' ),
								'value' => 'fontawesome',
							),
							'openiconic'  => array(
								'label' => esc_html__( 'Open Iconic', 'cheshalo' ),
								'value' => 'openiconic',
							),
							'typicons'    => array(
								'label' => esc_html__( 'Typicons', 'cheshalo' ),
								'value' => 'typicons',
							),
							'entypo'      => array(
								'label' => esc_html__( 'Entypo', 'cheshalo' ),
								'value' => 'entypo',
							),
							'linecons'    => array(
								'label' => esc_html__( 'Linecons', 'cheshalo' ),
								'value' => 'linecons',
							),
							'monosocial'  => array(
								'label' => esc_html__( 'Mono Social', 'cheshalo' ),
								'value' => 'monosocial',
							),
							'material'    => array(
								'label' => esc_html__( 'Material', 'cheshalo' ),
								'value' => 'material',
							),
						),
						'extra_class' => 'xts-hidden',
					),
					'icon_fontawesome'            => array(
						'id'          => 'icon_fontawesome',
						'title'       => esc_html__( 'Icon', 'cheshalo' ),
						'description' => esc_html__( 'Enter the class name of the icon. For example "fas fa-check".', 'cheshalo' ),
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Image', 'cheshalo' ),
						'type'        => 'text',
						'value'       => '',
						'requires'    => array(
							'icon_library' => array(
								'comparison' => 'equal',
								'value'      => 'fontawesome',
							),
						),
						'extra_class' => 'xts-hidden',
					),
					'icon_openiconic'             => array(
						'id'          => 'icon_openiconic',
						'title'       => esc_html__( 'Icon', 'cheshalo' ),
						'description' => esc_html__( 'Enter the class name of the icon. For example "oi oi-check".', 'cheshalo' ),
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Image', 'cheshalo' ),
						'type'        => 'text',
						'value'       => '',
						'requires'    => array(
							'icon_library' => array(
								'comparison' => 'equal',
								'value'      => 'openiconic',
							),
						),
						'extra_class' => 'xts-hidden',
					),
					'icon_typicons'               => array(
						'id'          => 'icon_typicons',
						'title'       => esc_html__( 'Icon', 'cheshalo' ),
						'description' => esc_html__( 'Enter the class name of the icon. For example "typcn typcn-input-checked".', 'cheshalo' ),
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Image', 'cheshalo' ),
						'type'        => 'text',
						'value'       => '',
						'requires'    => array(
							'icon_library' => array(
								'comparison' => 'equal',
								'value'      => 'typicons',
							),
						),
						'extra_class' => 'xts-hidden',
					),
					'icon_entypo'                 => array(
						'id'          => 'icon_entypo',
						'title'       => esc_html__( 'Icon', 'cheshalo' ),
						'description' => esc_html__( 'Enter the class name of the icon. For example "entypo-icon entypo-icon-check".', 'cheshalo' ),
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Image', 'cheshalo' ),
						'type'        => 'text',
						'value'       => '',
						'requires'    => array(
							'icon_library' => array(
								'comparison' => 'equal',
								'value'      => 'entypo',
							),
						),
						'extra_class' => 'xts-hidden',
					),
					'icon_linecons'               => array(
						'id'          => 'icon_linecons',
						'title'       => esc_html__( 'Icon', 'cheshalo' ),
						'description' => esc_html__( 'Enter the class name of the icon. For example "vc_li vc_li-star".', 'cheshalo' ),
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Image', 'cheshalo' ),
						'type'        => 'text',
						'value'       => '',
						'requires'    => array(
							'icon_library' => array(
								'comparison' => 'equal',
								'value'      => 'linecons',
							),
						),
						'extra_class' => 'xts-hidden',
					),
					'icon_monosocial'             => array(
						'id'          => 'icon_monosocial',
						'title'       => esc_html__( 'Icon', 'cheshalo' ),
						'description' => esc_html__( 'Enter the class name of the icon. For example "vc-mono vc-mono-addme".', 'cheshalo' ),
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Image', 'cheshalo' ),
						'type'        => 'text',
						'value'       => '',
						'requires'    => array(
							'icon_library' => array(
								'comparison' => 'equal',
								'value'      => 'monosocial',
							),
						),
						'extra_class' => 'xts-hidden',
					),
					'icon_material'               => array(
						'id'          => 'icon_material',
						'title'       => esc_html__( 'Icon', 'cheshalo' ),
						'description' => esc_html__( 'Enter the class name of the icon. For example "vc-material vc-material-check".', 'cheshalo' ),
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Image', 'cheshalo' ),
						'type'        => 'text',
						'value'       => '',
						'requires'    => array(
							'icon_library' => array(
								'comparison' => 'equal',
								'value'      => 'material',
							),
						),
						'extra_class' => 'xts-hidden',
					),
					'image'                       => array(
						'id'          => 'image',
						'title'       => esc_html__( 'Image', 'cheshalo' ),
						'group'       => esc_html__( 'Image', 'cheshalo' ),
						'type'        => 'image',
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'value'       => '',
						'extra_class' => 'xts-col-6',
					),
					'img_size'                    => array(
						'id'          => 'img_size',
						'title'       => esc_html__( 'Image size', 'cheshalo' ),
						'type'        => 'text',
						'tab'         => esc_html__( 'Style', 'cheshalo' ),
						'group'       => esc_html__( 'Image', 'cheshalo' ),
						'value'       => '',
						'description' => esc_html__( 'Example: \'thumbnail\', \'medium\', \'large\', \'full\' or enter image size in pixels: \'200x100\'.', 'cheshalo' ),
						'extra_class' => 'xts-col-6',
					),
					'icon_position'               => array(
						'id'      => 'icon_position',
						'title'   => esc_html__( 'Button image position', 'cheshalo' ),
						'tab'     => esc_html__( 'Style', 'cheshalo' ),
						'group'   => esc_html__( 'Image', 'cheshalo' ),
						'type'    => 'selector',
						'value'   => 'left',
						'options' => array(
							'left'  => array(
								'label' => esc_html__( 'Left', 'cheshalo' ),
								'value' => 'left',
							),
							'right' => array(
								'label' => esc_html__( 'Right', 'cheshalo' ),
								'value' => 'right',
							),
						),
					),
				),
			);
		}
	}
}
