<?php
/**
 * Archive products map.
 *
 * @package Cheshalo
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Direct access not allowed.
}

if ( ! function_exists( 'cheshalo_get_vc_map_shop_archive_products' ) ) {
	/**
	 * Archive products map.
	 */
	function cheshalo_get_vc_map_shop_archive_products() {
		return array(
			'base'        => 'cheshalo_shop_archive_products',
			'name'        => esc_html__( 'Archive products', 'cheshalo' ),
			'category'    => cheshalo_get_tab_title_category_for_wpb( esc_html__( 'Products archive', 'cheshalo' ), 'shop_archive' ),
			'description' => esc_html__( 'Show WooCommerce product grid', 'cheshalo' ),
			'icon'        => CHESHALO_ASSETS . '/images/vc-icon/sa-icons/sa-archive-products.svg',
			'params'      => array(
				array(
					'type'       => 'cheshalo_css_id',
					'param_name' => 'cheshalo_css_id',
				),

				array(
					'heading'          => esc_html__( 'Products view', 'cheshalo' ),
					'type'             => 'dropdown',
					'param_name'       => 'products_view',
					'value'            => array(
						esc_html__( 'Inherit', 'cheshalo' ) => 'inherit',
						esc_html__( 'Grid', 'cheshalo' ) => 'grid',
						esc_html__( 'List', 'cheshalo' ) => 'list',
					),
					'std'              => 'inherit',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'heading'          => esc_html__( 'Products columns', 'cheshalo' ),
					'hint'             => esc_html__( 'How many products you want to show per row.', 'cheshalo' ),
					'type'             => 'wd_select',
					'param_name'       => 'products_columns',
					'style'            => 'select',
					'selectors'        => array(),
					'devices'          => array(
						'desktop' => array(
							'value' => 'inherit',
						),
						'tablet'  => array(
							'value' => 'inherit',
						),
						'mobile'  => array(
							'value' => 'inherit',
						),
					),
					'value'            => array(
						esc_html__( 'Inherit', 'cheshalo' ) => 'inherit',
						esc_html__( '1', 'cheshalo' ) => '1',
						esc_html__( '2', 'cheshalo' ) => '2',
						esc_html__( '3', 'cheshalo' ) => '3',
						esc_html__( '4', 'cheshalo' ) => '4',
						esc_html__( '5', 'cheshalo' ) => '5',
						esc_html__( '6', 'cheshalo' ) => '6',
					),
					'dependency'       => array(
						'element'            => 'products_view',
						'value_not_equal_to' => 'list',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'heading'          => esc_html__( 'Space between products', 'cheshalo' ),
					'hint'             => esc_html__( 'You can set different spacing between blocks on shop page.', 'cheshalo' ),
					'type'             => 'wd_select',
					'param_name'       => 'products_spacing',
					'style'            => 'select',
					'selectors'        => array(),
					'devices'          => array(
						'desktop' => array(
							'value' => 'inherit',
						),
					),
					'value'            => array(
						esc_html__( 'Inherit', 'cheshalo' ) => 'inherit',
						esc_html__( '0', 'cheshalo' )  => '0',
						esc_html__( '2', 'cheshalo' )  => '2',
						esc_html__( '6', 'cheshalo' )  => '6',
						esc_html__( '10', 'cheshalo' ) => '10',
						esc_html__( '20', 'cheshalo' ) => '20',
						esc_html__( '30', 'cheshalo' ) => '30',
					),
					'dependency'       => array(
						'element'            => 'products_view',
						'value_not_equal_to' => 'list',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'heading'          => esc_html__( 'Products pagination', 'cheshalo' ),
					'hint'             => esc_html__( 'Choose a type for the pagination on your shop page.', 'cheshalo' ),
					'type'             => 'dropdown',
					'param_name'       => 'shop_pagination',
					'value'            => array(
						esc_html__( 'Inherit', 'cheshalo' )    => 'inherit',
						esc_html__( 'Pagination', 'cheshalo' ) => 'pagination',
						__( '"Load more" button', 'cheshalo' ) => 'more-btn',
						esc_html__( 'Infinite scrolling', 'cheshalo' ) => 'infinit',
					),
					'std'              => 'inherit',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'heading'      => esc_html__( 'Hover on product', 'cheshalo' ),
					'group'        => esc_html__( 'Design', 'cheshalo' ),
					'hint'         => esc_html__( 'Choose one of those hover effects for products', 'cheshalo' ),
					'type'         => 'cheshalo_image_select',
					'param_name'   => 'product_hover',
					'value'        => array(
						esc_html__( 'Inherit from Theme Settings', 'cheshalo' ) => 'inherit',
						esc_html__( 'Full info on hover', 'cheshalo' ) => 'info-alt',
						esc_html__( 'Full info on image', 'cheshalo' ) => 'info',
						esc_html__( 'Icons and "add to cart" on hover', 'cheshalo' ) => 'alt',
						esc_html__( 'Icons on hover', 'cheshalo' ) => 'icons',
						esc_html__( 'Quick', 'cheshalo' ) => 'quick',
						esc_html__( 'Show button on hover on image', 'cheshalo' ) => 'button',
						esc_html__( 'Show summary on hover', 'cheshalo' ) => 'base',
						esc_html__( 'Standard button', 'cheshalo' ) => 'standard',
						esc_html__( 'Tiled', 'cheshalo' ) => 'tiled',
						esc_html__( 'Full width button', 'cheshalo' ) => 'fw-button',
					),
					'images_value' => array(
						'inherit'   => CHESHALO_ASSETS_IMAGES . '/settings/empty.jpg',
						'info-alt'  => CHESHALO_ASSETS_IMAGES . '/settings/hover/info-alt.jpg',
						'info'      => CHESHALO_ASSETS_IMAGES . '/settings/hover/info.jpg',
						'alt'       => CHESHALO_ASSETS_IMAGES . '/settings/hover/alt.jpg',
						'icons'     => CHESHALO_ASSETS_IMAGES . '/settings/hover/icons.jpg',
						'quick'     => CHESHALO_ASSETS_IMAGES . '/settings/hover/quick.jpg',
						'button'    => CHESHALO_ASSETS_IMAGES . '/settings/hover/button.jpg',
						'base'      => CHESHALO_ASSETS_IMAGES . '/settings/hover/base.jpg',
						'standard'  => CHESHALO_ASSETS_IMAGES . '/settings/hover/standard.jpg',
						'tiled'     => CHESHALO_ASSETS_IMAGES . '/settings/hover/tiled.jpg',
						'fw-button' => CHESHALO_ASSETS_IMAGES . '/settings/hover/fw-button.jpg',
					),
					'dependency'   => array(
						'element'            => 'products_view',
						'value_not_equal_to' => 'list',
					),
				),

				array(
					'heading'          => esc_html__( 'Images size', 'cheshalo' ),
					'group'            => esc_html__( 'Design', 'cheshalo' ),
					'type'             => 'textfield',
					'param_name'       => 'img_size',
					'hint'             => esc_html__( 'Enter image size. Example: \'thumbnail\', \'medium\', \'large\', \'full\' or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use \'thumbnail\' size.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'heading'    => esc_html__( 'Products color scheme', 'cheshalo' ),
					'group'      => esc_html__( 'Design', 'cheshalo' ),
					'type'       => 'dropdown',
					'param_name' => 'products_color_scheme',
					'std'        => 'inherit',
					'value'      => array(
						esc_html__( 'Inherit', 'cheshalo' ) => 'inherit',
						esc_html__( 'Default', 'cheshalo' ) => 'default',
						esc_html__( 'Dark', 'cheshalo' )  => 'dark',
						esc_html__( 'Light', 'cheshalo' ) => 'light',
					),
				),

				array(
					'heading'          => esc_html__( 'Bordered grid', 'cheshalo' ),
					'group'            => esc_html__( 'Design', 'cheshalo' ),
					'type'             => 'dropdown',
					'param_name'       => 'products_bordered_grid',
					'value'            => array(
						esc_html__( 'Inherit', 'cheshalo' ) => 'inherit',
						esc_html__( 'Enable', 'cheshalo' ) => 'enable',
						esc_html__( 'Disable', 'cheshalo' ) => 'disable',
					),
					'std'              => 'inherit',
					'edit_field_class' => 'vc_col-sm-12 vc_column',
				),

				array(
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Bordered grid style', 'cheshalo' ),
					'param_name'       => 'products_bordered_grid_style',
					'value'            => array(
						esc_html__( 'Inherit', 'cheshalo' ) => 'inherit',
						esc_html__( 'Outside', 'cheshalo' ) => 'outside',
						esc_html__( 'Inside', 'cheshalo' ) => 'inside',
					),
					'std'              => 'inherit',
					'group'            => esc_html__( 'Design', 'cheshalo' ),
					'dependency'       => array(
						'element' => 'products_bordered_grid',
						'value'   => 'enable',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'heading'    => esc_html__( 'Products background', 'cheshalo' ),
					'hint'       => esc_html__( 'Add a background to the products in your grid.', 'cheshalo' ),
					'group'      => esc_html__( 'Design', 'cheshalo' ),
					'type'       => 'dropdown',
					'param_name' => 'products_with_background',
					'std'        => 'inherit',
					'value'      => array(
						esc_html__( 'Inherit', 'cheshalo' ) => 'inherit',
						esc_html__( 'Yes', 'cheshalo' ) => 'yes',
						esc_html__( 'No', 'cheshalo' )  => 'no',
					),
				),

				array(
					'heading'    => esc_html__( 'Custom products background color', 'cheshalo' ),
					'hint'       => esc_html__( 'Set custom background color for products.', 'cheshalo' ),
					'group'      => esc_html__( 'Design', 'cheshalo' ),
					'type'       => 'wd_colorpicker',
					'param_name' => 'products_background',
					'selectors'  => array(
						'{{WRAPPER}} .wd-products-with-bg, {{WRAPPER}} .wd-products-with-bg .product-grid-item' => array(
							'--wd-prod-bg:{{VALUE}}; --wd-bordered-bg:{{VALUE}};',
						),
					),
					'dependency' => array(
						'element' => 'products_with_background',
						'value'   => array( 'yes' ),
					),
				),

				array(
					'heading'    => esc_html__( 'Products shadow', 'cheshalo' ),
					'hint'       => esc_html__( 'Add a shadow to products if the initial product style did not have one.', 'cheshalo' ),
					'group'      => esc_html__( 'Design', 'cheshalo' ),
					'type'       => 'dropdown',
					'param_name' => 'products_shadow',
					'default'    => 'inherit',
					'value'      => array(
						esc_html__( 'Inherit', 'cheshalo' ) => 'inherit',
						esc_html__( 'Yes', 'cheshalo' ) => 'yes',
						esc_html__( 'No', 'cheshalo' )  => 'no',
					),
				),

				array(
					'heading'    => esc_html__( 'CSS box', 'cheshalo' ),
					'group'      => esc_html__( 'Design Options', 'js_composer' ),
					'type'       => 'css_editor',
					'param_name' => 'css',
				),
				cheshalo_get_vc_responsive_spacing_map(),

				// Width option (with dependency Columns option, responsive).
				cheshalo_get_responsive_dependency_width_map( 'responsive_tabs' ),
				cheshalo_get_responsive_dependency_width_map( 'width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'width_mobile' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_mobile' ),
			),
		);
	}
}
