<?php
/**
 * Gallery map.
 *
 * @package Cheshalo
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Direct access not allowed.
}

if ( ! function_exists( 'cheshalo_get_vc_map_single_product_gallery' ) ) {
	/**
	 * Gallery map.
	 */
	function cheshalo_get_vc_map_single_product_gallery() {
		return array(
			'base'        => 'cheshalo_single_product_gallery',
			'name'        => esc_html__( 'Product gallery', 'cheshalo' ),
			'category'    => cheshalo_get_tab_title_category_for_wpb( esc_html__( 'Single product elements', 'cheshalo' ), 'single_product' ),
			'description' => esc_html__( 'Featured image and product gallery', 'cheshalo' ),
			'icon'        => CHESHALO_ASSETS . '/images/vc-icon/sp-icons/sp-gallery.svg',
			'params'      => array(
				array(
					'type'       => 'cheshalo_css_id',
					'param_name' => 'cheshalo_css_id',
				),

				array(
					'heading'          => esc_html__( 'Thumbnails position', 'cheshalo' ),
					'type'             => 'dropdown',
					'param_name'       => 'thumbnails_position',
					'description'      => esc_html__( 'Set your thumbnails display or leave default set from Theme Settings.', 'cheshalo' ),
					'value'            => array(
						esc_html__( 'Inherit from Theme Settings', 'cheshalo' )  => 'inherit',
						esc_html__( 'Left (vertical position)', 'cheshalo' )     => 'left',
						esc_html__( 'Bottom (horizontal carousel)', 'cheshalo' ) => 'bottom',
						esc_html__( 'Bottom (1 column)', 'cheshalo' )            => 'bottom_column',
						esc_html__( 'Bottom (2 columns)', 'cheshalo' )           => 'bottom_grid',
						esc_html__( 'Carousel (2 columns)', 'cheshalo' )         => 'carousel_two_columns',
						esc_html__( 'Combined grid', 'cheshalo' )                => 'bottom_combined',
						esc_html__( 'Centered', 'cheshalo' )                     => 'centered',
						esc_html__( 'Without', 'cheshalo' )                      => 'without',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'type'       => 'dropdown',
					'heading'    => esc_html__( 'Thumbnails per slide', 'cheshalo' ),
					'param_name' => 'thumbnails_left_vertical_columns',
					'value'      => array(
						esc_html__( 'Inherit from Theme Settings', 'cheshalo' ) => 'inherit',
						esc_html__( 'Default', 'cheshalo' ) => 'default',
						'2' => '2',
						'3' => '3',
						'4' => '4',
						'5' => '5',
						'6' => '6',
					),
					'std'        => 'inherit',
					'dependency' => array(
						'element' => 'thumbnails_position',
						'value'   => array( 'left' ),
					),
				),

				array(
					'type'             => 'cheshalo_button_set',
					'heading'          => esc_html__( 'Thumbnails per slide', 'cheshalo' ),
					'param_name'       => 'thumbnails_bottom_columns_tabs',
					'tabs'             => true,
					'value'            => array(
						esc_html__( 'Desktop', 'cheshalo' ) => 'desktop',
						esc_html__( 'Tablet', 'cheshalo' ) => 'tablet',
						esc_html__( 'Mobile', 'cheshalo' ) => 'mobile',
					),
					'default'          => 'desktop',
					'dependency'       => array(
						'element' => 'thumbnails_position',
						'value'   => array( 'bottom' ),
					),
					'edit_field_class' => 'wd-res-control wd-custom-width vc_col-sm-12 vc_column',
				),

				array(
					'type'             => 'dropdown',
					'param_name'       => 'thumbnails_bottom_columns_desktop',
					'value'            => array(
						esc_html__( 'Inherit from Theme Settings', 'cheshalo' ) => 'inherit',
						'2' => '2',
						'3' => '3',
						'4' => '4',
						'5' => '5',
						'6' => '6',
					),
					'std'              => 'inherit',
					'dependency'       => array(
						'element' => 'thumbnails_position',
						'value'   => array( 'bottom' ),
					),
					'wd_dependency'    => array(
						'element' => 'thumbnails_bottom_columns_tabs',
						'value'   => array( 'desktop' ),
					),
					'edit_field_class' => 'wd-res-item vc_col-sm-12 vc_column',
				),

				array(
					'type'             => 'dropdown',
					'param_name'       => 'thumbnails_bottom_columns_tablet',
					'value'            => array(
						esc_html__( 'Inherit from Theme Settings', 'cheshalo' ) => 'inherit',
						'2' => '2',
						'3' => '3',
						'4' => '4',
						'5' => '5',
						'6' => '6',
					),
					'std'              => 'inherit',
					'dependency'       => array(
						'element' => 'thumbnails_position',
						'value'   => array( 'bottom' ),
					),
					'wd_dependency'    => array(
						'element' => 'thumbnails_bottom_columns_tabs',
						'value'   => array( 'tablet' ),
					),
					'edit_field_class' => 'wd-res-item vc_col-sm-12 vc_column',
				),

				array(
					'type'             => 'dropdown',
					'param_name'       => 'thumbnails_bottom_columns_mobile',
					'value'            => array(
						esc_html__( 'Inherit from Theme Settings', 'cheshalo' ) => 'inherit',
						'2' => '2',
						'3' => '3',
						'4' => '4',
						'5' => '5',
						'6' => '6',
					),
					'std'              => 'inherit',
					'dependency'       => array(
						'element' => 'thumbnails_position',
						'value'   => array( 'bottom' ),
					),
					'wd_dependency'    => array(
						'element' => 'thumbnails_bottom_columns_tabs',
						'value'   => array( 'mobile' ),
					),
					'edit_field_class' => 'wd-res-item vc_col-sm-12 vc_column',
				),

				array(
					'heading'    => esc_html__( 'CSS box', 'cheshalo' ),
					'group'      => esc_html__( 'Design Options', 'js_composer' ),
					'type'       => 'css_editor',
					'param_name' => 'css',
				),
				cheshalo_get_vc_responsive_spacing_map(),
			),
		);
	}
}

add_filter( 'vc_autocomplete_cheshalo_single_product_gallery_product_id_callback', 'cheshalo_productIdAutocompleteSuggester_new', 10, 1 );
add_filter( 'vc_autocomplete_cheshalo_single_product_gallery_product_id_render', 'cheshalo_productIdAutocompleteRender', 10, 1 );
